# This file was auto-generated by Fern from our API Definition.

import typing

ExtractRequestConfigChunkingMethod = typing.Union[typing.Literal["none", "sentence", "paragraph", "topics"], typing.Any]
